@@ -13,7 +13,7 @@ from ..helpers import timeline as TIMELINE
 from ..helpers import urls
 from . import base
 
-_LOGGER = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 class Camera(base.Device):
@@ -39,21 +39,21 @@ class Camera(base.Device):
         try:
             response = self._client.send_request("put", url)
 
-            _LOGGER.debug("Capture image response: %s", response.text)
+            log.debug("Capture image response: %s", response.text)
 
             return True
 
         except jaraco.abode.Exception as exc:
-            _LOGGER.warning("Failed to capture image: %s", exc)
+            log.warning("Failed to capture image: %s", exc)
 
         return False
 
     def refresh_image(self):
         """Get the most recent camera image."""
-        url = urls.TIMELINE_IMAGES_ID.format(device_id=self.device_id)
+        url = urls.TIMELINE_IMAGES_ID.format(device_id=self.id)
         response = self._client.send_request("get", url)
 
-        _LOGGER.debug("Get image response: %s", response.text)
+        log.debug("Get image response: %s", response.text)
 
         return self.update_image_location(response.json())
 
@@ -82,7 +82,7 @@ class Camera(base.Device):
         response = self._client.send_request("head", file_path)
 
         if response.status_code != 302:
-            _LOGGER.warning(
+            log.warning(
                 "Unexected response code %s with body: %s",
                 str(response.status_code),
                 response.text,
@@ -108,7 +108,7 @@ class Camera(base.Device):
         response = requests.get(self.image_url, stream=True)
 
         if response.status_code != 200:
-            _LOGGER.warning(
+            log.warning(
                 "Unexpected response code %s when requesting image: %s",
                 str(response.status_code),
                 response.text,
@@ -122,18 +122,18 @@ class Camera(base.Device):
 
     def snapshot(self):
         """Request the current camera snapshot as a base64-encoded string."""
-        url = f"{urls.CAMERA_INTEGRATIONS}{self._device_uuid}/snapshot"
+        url = f"{urls.CAMERA_INTEGRATIONS}{self.uuid}/snapshot"
 
         try:
             response = self._client.send_request("post", url)
-            _LOGGER.debug("Camera snapshot response: %s", response.text)
+            log.debug("Camera snapshot response: %s", response.text)
         except jaraco.abode.Exception as exc:
-            _LOGGER.warning("Failed to get camera snapshot image: %s", exc)
+            log.warning("Failed to get camera snapshot image: %s", exc)
             return False
 
         self._snapshot_base64 = response.json().get("base64Image")
         if self._snapshot_base64 is None:
-            _LOGGER.warning("Camera snapshot data missing")
+            log.warning("Camera snapshot data missing")
             return False
 
         return True
@@ -148,7 +148,7 @@ class Camera(base.Device):
             with open(path, "wb") as imgfile:
                 imgfile.write(base64.b64decode(self._snapshot_base64))
         except OSError as exc:
-            _LOGGER.warning("Failed to write snapshot image to file: %s", exc)
+            log.warning("Failed to write snapshot image to file: %s", exc)
             return False
 
         return True
@@ -166,13 +166,13 @@ class Camera(base.Device):
         if self._state['privacy']:
             privacy = '1' if enable else '0'
 
-            path = urls.PARAMS + self.device_id
+            path = urls.PARAMS + self.id
 
             camera_data = {
                 'mac': self._state['camera_mac'],
                 'privacy': privacy,
                 'action': 'setParam',
-                'id': self.device_id,
+                'id': self.id,
             }
 
             response = self._client.send_request(
@@ -180,15 +180,15 @@ class Camera(base.Device):
             )
             response_object = response.json()
 
-            _LOGGER.debug("Camera Privacy Mode Response: %s", response.text)
+            log.debug("Camera Privacy Mode Response: %s", response.text)
 
-            if response_object['id'] != self.device_id:
+            if response_object['id'] != self.id:
                 raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
             if response_object['privacy'] != str(privacy):
                 raise jaraco.abode.Exception(ERROR.SET_PRIVACY_MODE)
 
-            _LOGGER.info("Set camera %s privacy mode to: %s", self.device_id, privacy)
+            log.info("Set camera %s privacy mode to: %s", self.id, privacy)
 
             return True
 
