@@ -10,7 +10,7 @@ from .control import needs_control_url
 from .switch import Switch
 
 
-_LOGGER = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 class Light(Switch):
@@ -21,7 +21,7 @@ class Light(Switch):
     @needs_control_url
     def set_color_temp(self, color_temp):
         """Set device color."""
-        url = urls.INTEGRATIONS + self._device_uuid
+        url = urls.INTEGRATIONS + self.uuid
 
         color_data = {
             'action': 'setcolortemperature',
@@ -31,18 +31,18 @@ class Light(Switch):
         response = self._client.send_request("post", url, data=color_data)
         response_object = response.json()
 
-        _LOGGER.debug("Set Color Temp Response: %s", response.text)
+        log.debug("Set Color Temp Response: %s", response.text)
 
-        if response_object['idForPanel'] != self.device_id:
+        if response_object['idForPanel'] != self.id:
             raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
         if response_object['colorTemperature'] != int(color_temp):
-            _LOGGER.warning(
+            log.warning(
                 (
                     "Set color temp mismatch for device %s. "
                     "Request val: %s, Response val: %s "
                 ),
-                self.device_id,
+                self.id,
                 color_temp,
                 response_object['colorTemperature'],
             )
@@ -51,12 +51,12 @@ class Light(Switch):
 
         self.update({'statuses': {'color_temp': color_temp}})
 
-        _LOGGER.info("Set device %s color_temp to: %s", self.device_id, color_temp)
+        log.info("Set device %s color_temp to: %s", self.id, color_temp)
 
     @needs_control_url
     def set_color(self, color):
         """Set device color."""
-        url = urls.INTEGRATIONS + self._device_uuid
+        url = urls.INTEGRATIONS + self.uuid
 
         hue, saturation = color
         color_data = {
@@ -68,20 +68,20 @@ class Light(Switch):
         response = self._client.send_request("post", url, data=color_data)
         response_object = response.json()
 
-        _LOGGER.debug("Set Color Response: %s", response.text)
+        log.debug("Set Color Response: %s", response.text)
 
-        if response_object['idForPanel'] != self.device_id:
+        if response_object['idForPanel'] != self.id:
             raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
         # Abode will sometimes return hue value off by 1 (rounding error)
         hue_comparison = math.isclose(response_object["hue"], int(hue), abs_tol=1)
         if not hue_comparison or (response_object["saturation"] != int(saturation)):
-            _LOGGER.warning(
+            log.warning(
                 (
                     "Set color mismatch for device %s. "
                     "Request val: %s, Response val: %s "
                 ),
-                self.device_id,
+                self.id,
                 (hue, saturation),
                 (response_object['hue'], response_object['saturation']),
             )
@@ -91,7 +91,7 @@ class Light(Switch):
 
         self.update({'statuses': {'hue': hue, 'saturation': saturation}})
 
-        _LOGGER.info("Set device %s color to: %s", self.device_id, (hue, saturation))
+        log.info("Set device %s color to: %s", self.id, (hue, saturation))
 
     @property
     def brightness(self):
@@ -128,9 +128,9 @@ class Light(Switch):
     @property
     def is_color_capable(self):
         """Device is color compatible."""
-        return 'RGB' in self._type
+        return 'RGB' in self.type
 
     @property
     def is_dimmable(self):
         """Device is dimmable."""
-        return 'Dimmer' in self._type
+        return 'Dimmer' in self.type
