@@ -1,12 +1,14 @@
 """Abode lock device."""
 
-from ..devices import AbodeDevice
 from ..helpers import constants as CONST
+from . import base
 
 
-class AbodeLock(AbodeDevice):
+class Lock(base.Device):
     """Class to represent a door lock."""
 
+    implements = CONST.TYPE_LOCK
+
     def lock(self):
         """Lock the device."""
         success = self.set_status(CONST.STATUS_LOCKCLOSED_INT)
