@@ -1,12 +1,14 @@
 """Abode valve device."""
 
-from ..devices.switch import AbodeSwitch
 from ..helpers import constants as CONST
+from .switch import Switch
 
 
-class AbodeValve(AbodeSwitch):
+class Valve(Switch):
     """Class to add valve functionality."""
 
+    implements = CONST.TYPE_VALVE
+
     def switch_on(self):
         """Open the valve."""
         success = self.set_status(CONST.STATUS_ON_INT)
