@@ -1,8 +1,6 @@
 """Mock Abode Power Switch Sensor Device."""
 import jaraco.abode.helpers.constants as CONST
 
-from .. import dump
-
 DEVICE_ID = 'ZW:00000105'
 CONTROL_URL = 'api/v1/control/light/' + DEVICE_ID
 
@@ -15,7 +13,7 @@ def device(
     no_response=False,
 ):
     """Dimmer mock device."""
-    return dump(
+    return dict(
         id=devid,
         type_tag='device_type.dimmer',
         type='Dimmer',
